@@ -45,6 +45,7 @@ class Oracle(Dialect):
     NULL_ORDERING = "nulls_are_large"
     ON_CONDITION_EMPTY_BEFORE_ERROR = False
     ALTER_TABLE_ADD_REQUIRED_FOR_EACH_COLUMN = False
+    DISABLES_ALIAS_REF_EXPANSION = True
 
     # See section 8: https://docs.oracle.com/cd/A97630_01/server.920/a96540/sql_elements9a.htm
     NORMALIZATION_STRATEGY = NormalizationStrategy.UPPERCASE
@@ -74,15 +75,12 @@ class Oracle(Dialect):
 
     PSEUDOCOLUMNS = {"ROWNUM", "ROWID", "OBJECT_ID", "OBJECT_VALUE", "LEVEL"}
 
-    def quote_identifier(self, expression: E, identify: bool = True) -> E:
+    def can_quote(self, identifier: exp.Identifier, identify: str | bool = "safe") -> bool:
         # Disable quoting for pseudocolumns as it may break queries e.g
         # `WHERE "ROWNUM" = ...` does not work but `WHERE ROWNUM = ...` does
-        if isinstance(expression, exp.Identifier) and isinstance(
-            expression.parent, exp.Pseudocolumn
-        ):
-            return expression
-
-        return super().quote_identifier(expression, identify=identify)
+        return (
+            identifier.quoted or not isinstance(identifier.parent, exp.Pseudocolumn)
+        ) and super().can_quote(identifier, identify=identify)
 
     class Tokenizer(tokens.Tokenizer):
         VAR_SINGLE_TOKENS = {"@", "$", "#"}
@@ -131,6 +129,7 @@ class Oracle(Dialect):
                 unabbreviate=False,
             ),
         }
+        FUNCTIONS.pop("TO_BOOLEAN")
 
         NO_PAREN_FUNCTION_PARSERS = {
             **parser.Parser.NO_PAREN_FUNCTION_PARSERS,
@@ -276,6 +275,24 @@ class Oracle(Dialect):
         def _parse_connect_with_prior(self):
             return self._parse_assignment()
 
+        def _parse_insert_table(self) -> t.Optional[exp.Expression]:
+            # Oracle does not use AS for INSERT INTO alias
+            # https://docs.oracle.com/en/database/oracle/oracle-database/18/sqlrf/INSERT.html
+            # Parse table parts without schema to avoid parsing the alias with its columns
+            this = self._parse_table_parts(schema=True)
+
+            if isinstance(this, exp.Table):
+                alias_name = self._parse_id_var(any_token=False)
+                if alias_name:
+                    this.set("alias", exp.TableAlias(this=alias_name))
+
+                this.set("partition", self._parse_partition())
+
+                # Now parse the schema (column list) if present
+                return self._parse_schema(this=this)
+
+            return this
+
     class Generator(generator.Generator):
         LOCKING_READS_SUPPORTED = True
         JOIN_HINTS = False
